@@ -121,20 +121,41 @@ class OQWidgetList(OQListView):
         self.__fit_to_contents = False
         self.__minimum_fit_size = 0
         self.__maximum_fit_size = _MAXIMUM_SIZE
+        self.__update_layout_timer = QtCore.QTimer()
+
+        # Update layout timer.
+        self.__update_layout_timer.setSingleShot(True)
+        try:
+            self.__update_layout_timer.setTimerType(QtCore.Qt.CoarseTimer)
+        except AttributeError:
+            pass
+        self.__update_layout_timer.timeout.connect(self.__update_layout)
 
         # Set item delegate and internal model.
         super(OQWidgetList, self).setItemDelegate(self.__delegate)
         super(OQWidgetList, self).setModel(self.__model)
 
-    def __updateLayout__(self):
+    @QtCore.Slot()
+    def __update_layout(self):
 
         # Fit to contents, need to calculate fixed size.
         if self.__fit_to_contents:
 
+            # Process events.
+            QtWidgets.QApplication.instance().processEvents()
+
             # Prepare initial information.
-            size = 3
+            size = 0
             maximum_size = self.__maximum_fit_size
             flow = self.flow()
+            spacing = self.spacing()
+
+            # Add margin to initial size.
+            margins = self.contentsMargins()
+            if flow == QtWidgets.QListView.LeftToRight:
+                size += margins.left() + margins.right()
+            else:
+                size += margins.top() + margins.bottom()
 
             # For every widget.
             for widget in self.editors() or ():
@@ -145,6 +166,7 @@ class OQWidgetList(OQListView):
                     size += widget_size_hint.width()
                 else:
                     size += widget_size_hint.height()
+                size += 2 * spacing
 
                 # Exceeded maximum fit size, clamp and stop adding.
                 if maximum_size is not None and size > maximum_size:
@@ -182,6 +204,12 @@ class OQWidgetList(OQListView):
         # Emit layout changed signal.
         self.__model.layoutChanged.emit()
 
+    def __updateLayout__(self):
+        """Update layout."""
+
+        # De-bounce (prevents being called too many times).
+        self.__update_layout_timer.start(10)
+
     @QtCore.Slot()
     def __fixScrolling(self):
 
